aboutsummaryrefslogtreecommitdiff
path: root/check-format.sh
diff options
context:
space:
mode:
Diffstat (limited to 'check-format.sh')
-rwxr-xr-xcheck-format.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/check-format.sh b/check-format.sh
index 7de2bd2c..be8f9d78 100755
--- a/check-format.sh
+++ b/check-format.sh
@@ -1,7 +1,7 @@
#!/usr/bin/env bash
-# Arg used to specify non-'origin/master' comparison branch
-ORIGIN_BRANCH=${1:-"origin/master"}
+# Arg used to specify non-'origin/main' comparison branch
+ORIGIN_BRANCH=${1:-"origin/main"}
CLANG_BINARY=${2:-"`which clang-format-9`"}
# Run git-clang-format to check for violations